<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versió %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 és Software lliure, però el seu desenvolupament pren un temps preciós.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Siusplau &lt;a href=&apos;%1&apos;&gt;dóna&lt;/a&gt; per ajudar al desenvolupament continuat del %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Alliberat sota la &lt;a href=&apos;%1&apos;&gt;Llicència Pública General de GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tanca</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>El que sempre havíeu volgut saber sobre el %1 i mai us havíeu atrevit a preguntar</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>És possible que també vulgueu provar altres aplicacions meves:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, una aplicació de YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, un reproductor de música de YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Tradueix %1 al teu idioma utilitzant %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Llicenciat a: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Entra els detalls de la teva llicència</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Codi:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Si us plau, llicencia el %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Aquesta demo ha expirat.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Sense llicència, l&apos;aplicació caducarà en %1 dies</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Comprant la versió completa, també donarà suport al dur treball que he posat en la creació del %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Utilitza la demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Entra la lliçència </translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Comprar llicència</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>La versió completa us permet afegir més de %1 pistes a la llista de reproducció i escoltar la vostra música sense interrupcions</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Compra en %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Llegeix més</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Any</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularitat</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordre invers</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordena per</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Llegeix més</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Ordena per pista</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Ordena per àlbum</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Any</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularitat</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordre invers</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordena per</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Enrere</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Ves enrere</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvinguts al &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>El %1 necessita escanejar la vostra col·lecció de música.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Fes servir una col·lecció iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Usa %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Escull un directori...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 es connectarà als serveis web de Last.fm i els passarà els noms dels artistes i títols dels àlbums per trobar les portades, biografies i molt més.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Si li preocupa la privacitat d&apos;això pot sortir ara.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>On teniu la col·lecció de música?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Seleccioneu la ubicació de la col·lecció de música.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Busqueu la vostra col·lecció</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Neteja</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Ja s&apos;està executant un escaneig</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>El %1 està escanejant la vostra col·lecció de música.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>El %1 fa servir &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; per catalogar la vostra música.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Això prendrà temps, depenent de la mida de la vostra col·lecció i la velocitat de xarxa.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Aneu a fer un cafè</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descarregant actualitzacions...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Deixeu anar aquí per afegir a la llista de reproducció</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artistes</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Àlbums</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Carpetes</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reprodueix / Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Atura després de la pista actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Pista següent</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Augmenta el volum</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Disminueix el volum</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silencia</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Cerca endavant</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Cerca enrere</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Autentificació fallida</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Entra a %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>Nom d&apos;&amp;Usuari:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Contrassenya:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Crea un compte de %1</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Heu oblidat el vostre &lt;a href=&apos;%1&apos;&gt;Nom d&apos;Usuari&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;Contrassenya&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Enrere</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ves a la vista anterior</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Informació</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Mostra informació sobre la pista actual</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Previ</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Torna a la pista prèvia</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Següent</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Salta a la pista següent</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reprodueix</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Comença la reproducció</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pantalla &amp;completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ves a pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Esborra</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Esborra les pistes seleccionades de la llista de reproducció</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mou A&amp;munt</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Mou cap amunt les pistes seleccionades en la llista de reproducció</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mou A&amp;vall</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Mou cap avall les pistes seleccionades en la llista de reproducció</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adéu</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Canvia el directori de la col·lecció...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Trieu una carpeta de col·lecció de música diferent</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Pàgina &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 en la web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Feu una &amp;donació</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Siusplau recolza el desenvolupament continuat del %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informació sobre el %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Neteja</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Elimina totes les peces de la llista de reproducció</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Aleatori</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Mode aleatori de la llista de reproducció</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Repeteix</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Torna a reproduir la primera cançó després que hagin sonat totes les cançons</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silencia el volum</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicació</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reproducció</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Llista de reproducció</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Prem %1 per pujar el volum, %2 per baixar-lo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Obrint %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Actualitzant la col·lecció...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Actualitzant la col·lecció - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Col·lecció actualitzada</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Error fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Abandona la Pantalla &amp;completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Temps restant: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volum silenciat</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volum de-silenciat</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Aconsegueix la versió completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 la versió %2 ja està disponible.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recorda&apos;m-ho més tard</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualitza</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimitza</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tanca</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Compra %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Atura després d&apos;aquesta pista</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Envia les pistes reproduïdes a %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Surt de %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Informa d&apos;un problema...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 acaba d&apos;escanejar la vostra col·lecció de música</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>T&apos;&amp;Agrada %1? Puntua&apos;l!</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Deixa anar elements aquí</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Llista de reproducció finalitzada</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Això és només la versió de demostració del %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Li permet reproduir unes quantes pistes per provar l&apos;aplicació i veure si li va bé.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Aconsegueix la versió completa</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Una nova versió de %1 està disponible</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 estan disponibles. Tu tens %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>T&apos;agradaria descarregar-ho ara?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Omet aquesta versió</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Recorda-m&apos;ho després</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instal·la Actualització</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Enganxar</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Aquesta versió de prova és limitada a tan sols %1 pistes a la llista de reproducció.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Llista de reproducció buida</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 pistes - Longitud total de %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>La seva cerca no ha donat resultats.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Pistes</translation>
    </message>
</context>
</TS>